==> abasic_0_0_6_9.zip: abasic_0_0_6_9/Win32DLL/DllMain.cpp <==
#include <windows.h>
#include "../ap_if.h"

//C^v^̎s
volatile void WINAPI __stdcall start(void){
	basic_run();
}
volatile void WINAPI __stdcall run(void){
	basic_run();
}

//Tu[`̎s
volatile int WINAPI __stdcall _gosub(char*label){
	return basic_goto(label);
}
volatile int WINAPI __stdcall _goto(char*label){
	return basic_goto(label);
}

//֐̌Ăяo
volatile int WINAPI __stdcall _func(char*label){
	return basic_func(label);
}

//ϐɒlݒ肷
volatile void WINAPI __stdcall setVari(char*name,char*val){
	basic_setVari(name,val);
}

//ϐ̒l擾
volatile char* WINAPI __stdcall getVari(char*name){
	return basic_getVari(name);
}


BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
	if(basic_init()) MessageBox(NULL,"C^v^̏Ɏs܂\nC^v^̎st@CmFĂ","abasic",0);
    return TRUE;
}

//-------------------------------------------------------------------------------
/*
Win32DLL𗘗pꍇ̌Ăяo

include <windows.h>

typedef void (__stdcall*START)(void);
typedef int (__stdcall*GOSUB)(char*);
typedef int (__stdcall*_GOSUB)(char*);
typedef void (__stdcall*SETVARI)(char*,char*);
typedef char* (__stdcall*GETVARI)(char*);

int main(){
	//AhXԓɃ}bv
	HINSTANCE hDllInstance = ::LoadLibrary("./Win32DLL.dll");//DLLw

	// GNX|[gꂽ֐̃AhX擾
	START start=(START)::GetProcAddress(hDllInstance, "start"); //֐|C^DLL̊֐̌т
	_GOSUB _gosub=(_GOSUB)::GetProcAddress(hDllInstance, "_gosub");
	SETVARI setVari=(SETVARI)::GetProcAddress(hDllInstance, "setVari");
	GETVARI getVari=(GETVARI)::GetProcAddress(hDllInstance, "getVari");

	FreeLibrary(hDllInstance);//J
	return 0;
}


C#DLL𗘗pꍇ̌Ăяo
GC̍ĔzuɃ\bhĂԂNULLG[B
iOGCĂŌĂяoɍĔzuȂHvKvj

public class Form1
{
	[System.Runtime.InteropServices.DllImport("Win32DLL")]
	private extern static  void start();

	[System.Runtime.InteropServices.DllImport("Win32DLL")]
	private extern static  int gosub(string label);

	[System.Runtime.InteropServices.DllImport("Win32DLL")]
	private extern static  void setVari(string name,string val);

	[System.Runtime.InteropServices.DllImport("Win32DLL")]
	private extern static  string getVari(string name);
}

*/

==> abasic_0_0_7_6.zip: abasic_0_0_7_6/Win32DLL/DllMain.cpp <==
#include <windows.h>
#include "../ap_if.h"

//C^v^̎s
volatile void WINAPI __stdcall start(void){
	basic_run();
}
volatile void WINAPI __stdcall run(void){
	basic_run();
}

//Tu[`̎s
volatile int WINAPI __stdcall _gosub(char*label){
	return basic_goto(label);
}
volatile int WINAPI __stdcall _goto(char*label){
	return basic_goto(label);
}

//֐̌Ăяo
volatile int WINAPI __stdcall _func(char*label){
	return basic_func(label);
}

//ϐɒlݒ肷
volatile void WINAPI __stdcall setVari(char*name,char*val){
	basic_setVari(name,val);
}

//ϐ̒l擾
volatile char* WINAPI __stdcall getVari(char*name){
	return basic_getVari(name);
}


BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
	if(basic_load("main.txt")) MessageBox(NULL,"C^v^̏Ɏs܂\nC^v^̎st@CmFĂ","abasic",0);
    return TRUE;
}

//-------------------------------------------------------------------------------
/*
Win32DLL𗘗pꍇ̌Ăяo

include <windows.h>

typedef void (__stdcall*START)(void);
typedef int (__stdcall*GOSUB)(char*);
typedef int (__stdcall*_GOSUB)(char*);
typedef void (__stdcall*SETVARI)(char*,char*);
typedef char* (__stdcall*GETVARI)(char*);

int main(){
	//AhXԓɃ}bv
	HINSTANCE hDllInstance = ::LoadLibrary("./Win32DLL.dll");//DLLw

	// GNX|[gꂽ֐̃AhX擾
	START start=(START)::GetProcAddress(hDllInstance, "start"); //֐|C^DLL̊֐̌т
	_GOSUB _gosub=(_GOSUB)::GetProcAddress(hDllInstance, "_gosub");
	SETVARI setVari=(SETVARI)::GetProcAddress(hDllInstance, "setVari");
	GETVARI getVari=(GETVARI)::GetProcAddress(hDllInstance, "getVari");

	FreeLibrary(hDllInstance);//J
	return 0;
}


C#DLL𗘗pꍇ̌Ăяo
GC̍ĔzuɃ\bhĂԂNULLG[B
iOGCĂŌĂяoɍĔzuȂHvKvj

public class Form1
{
	[System.Runtime.InteropServices.DllImport("Win32DLL")]
	private extern static  void start();

	[System.Runtime.InteropServices.DllImport("Win32DLL")]
	private extern static  int gosub(string label);

	[System.Runtime.InteropServices.DllImport("Win32DLL")]
	private extern static  void setVari(string name,string val);

	[System.Runtime.InteropServices.DllImport("Win32DLL")]
	private extern static  string getVari(string name);
}

*/
